Pipenv is a production-ready tool that aims to bring the best of all packaging worlds to the Python world. It harnesses Pipfile, pip, and virtualenv into one single command.

It features very pretty terminal colors.

### Stay Informed

Receive updates on new releases and upcoming projects.

Follow @ThePyPA

Join Mailing List.

### Other Projects

- Pipenv-Pipes
- pip: package installer for Python
- Requests: HTTP for Humans

### Useful Links

- Pipenv @ GitHub
- Pipenv @ PyPI
- Pipenv PPA (PyPA)
- Issue Tracker

- 日本語
- Español